@@ -5,7 +5,7 @@ author: hugh@blinkybeach.com
 """
 from procuret.tests.variants.with_supplier import TestWithSupplier
 from procuret.tests.test_result import Success, TestResult
-from procuret.instalment_link import InstalmentLink
+from procuret.instalment_link import InstalmentLink, InstalmentLinkOpen
 from procuret.session import Session, Perspective
 from procuret.ancillary.communication_option import CommunicationOption
 from decimal import Decimal
@@ -13,7 +13,7 @@ from decimal import Decimal
 
 class ExerciseInstalmentLink(TestWithSupplier):
 
-    NAME = 'Create an InstalmentLink'
+    NAME = 'Create, retrieve and mark an InstalmentLink as opened'
 
     def execute(self) -> TestResult:
 
@@ -34,4 +34,26 @@ class ExerciseInstalmentLink(TestWithSupplier):
 
         assert isinstance(link, InstalmentLink)
 
+        r_link = InstalmentLink.retrieve(
+            public_id=link.public_id,
+            session=session
+        )
+
+        assert isinstance(r_link, InstalmentLink)
+        assert r_link.public_id == link.public_id
+
+        InstalmentLinkOpen.create(
+            link_id=r_link.public_id,
+            session=session
+        )
+
+        o_link = InstalmentLink.retrieve(
+            public_id=r_link.public_id,
+            session=session
+        )
+
+        assert isinstance(o_link, InstalmentLink)
+        assert len(o_link.opens) > 0
+        assert isinstance(o_link.opens[0], InstalmentLinkOpen)
+
         return Success()
